@@ -1,16 +1,6 @@
 /*                               -*- Mode: C -*- 
  * 
- * cutil.c -- 
- * ITIID           : $ITI$ $Header $__Header$
- * Author          : Ulrich Pfeifer
- * Created On      : Sun Sep 10 12:29:45 1995
- * Last Modified By: Ulrich Pfeifer
- * Last Modified On: Tue Nov 14 19:02:50 1995
- * Language        : C
- * Update Count    : 14
- * Status          : Unknown, Use with caution!
- * 
- * (C) Copyright 1995, Universitt Dortmund, all rights reserved.
+ * (C) Copyright 1995, Universitdt Dortmund, all rights reserved.
  * 
  */
 
@@ -25,6 +15,15 @@
    7/19/91  speed up substrcmp by ses@ccgr.technion.ac.il (Simon E Spero)
  *
  * $Log: cutil.c,v $
+ * Revision 1.2  1996/08/14 23:54:04  julia
+ * *** empty log message ***
+ *
+ * Revision 1.1.1.1  1996/06/04 20:36:07  julia
+ * autoconf baseline
+ *
+ * Revision 1.1.1.1  1996/04/30 18:22:13  dmitriy
+ * Version 2.1 -- autoconf baseline
+ *
  * Revision 2.0.1.5  1995/11/14 18:03:20  pfeifer
  * patch51:
  *
@@ -140,7 +139,7 @@
 */
 
 #ifndef lint
-static char *RCSid = "$Header: /usr/local/ls6/src+data/src/freeWAIS-sf-2.0/ir/RCS/cutil.c,v 2.0.1.5 1995/11/14 18:03:20 pfeifer Exp $";
+static char *RCSid = "$Header: /usr/local/cvs/wais/freeWAIS-sf-2.1/ir/cutil.c,v 1.2 1996/08/14 23:54:04 julia Exp $";
 #endif
 
 #define _C_C_util_
@@ -148,7 +147,8 @@ static char *RCSid = "$Header: /usr/local/ls6/src+data/src/freeWAIS-sf-2.0/ir/RC
 #include "cutil.h"
 #include "panic.h"
 
-#include <ctype.h>
+#include <ctype.h> /* local version redefines string functions */             
+
 /*----------------------------------------------------------------------*/
 
 /* #define MEMORY_ACCOUNTING */
@@ -245,7 +245,6 @@ size_t size;
   fprintf(memRecord,"malloced %lu bytes at %lu\n",size,ptr);
   flushMemAcct();
 #endif
-
   return(ptr);
 }
 
@@ -297,27 +296,9 @@ fs_free(ptr)
 void* ptr;
 /* does safety checks and optional accounting */
 {
-#ifdef MEMORY_ACCOUNTING
-  prepMemAcct();
-  /* note that the sizeof a pointer is always 4.  If only we could find out
-     how much space that pointer was pointing to.  Oh well, this is a place
-     holder for now
-   */
-  fprintf(memRecord,"freed %lu bytes at %lu\n",(size_t)sizeof(ptr),ptr);
-  flushMemAcct();
 
-  /* look for specific ptr (useful when tracking un-freed memory) */
-  if (ptr == badPtr) warn("bad ptr in free");
-#endif
-
-  if (ptr != NULL)		/* some non-ansi compilers/os's cant handle freeing null */
-    {				/* if we knew the size of this block of memory, we could clear it - oh well */
-#ifdef THINK_C
-      DisposPtr(ptr);
-#else
-      free(ptr);
-#endif
-    }
+  if (ptr != NULL) free(ptr);
+    
 }
 
 /*----------------------------------------------------------------------*/
@@ -415,7 +396,7 @@ long c;
     return(IS_DELIMITER);
 }
 
-typedef boolean (boolfunc) _AP((long c));
+typedef boolean (boolfunc) (long c);
 
 char*
 strtokf(s1,isDelimiter)
@@ -530,8 +511,6 @@ char* s1;
 
 /*----------------------------------------------------------------------*/
 
-#ifdef ANSI_LIKE /* use ansi varargs */
-
 long
 cprintf(boolean print, char* format, ...)
 /* just like printf, but only prints if the first argument = 1 */
@@ -539,7 +518,11 @@ cprintf(boolean print, char* format, ...)
   va_list ap;			/* the variable arguments */
   if (print == 1)
     { long res;
+#ifdef STDC_HEADERS
       va_start(ap,format);	/* init ap */
+#else
+      va_start(ap);
+#endif
       res = vprintf(format,ap);	/* print the contents */
       va_end(ap);		/* free ap */
       return(res);
@@ -548,35 +531,7 @@ cprintf(boolean print, char* format, ...)
     return(0);
 }
 
-#else /* use k&r varargs */
 
-long
-cprintf(va_alist)
-va_dcl
-/* just like printf, but only prints if the first argument = 1 */
-{
-  va_list ap;			/* the variable arguments */
-  boolean print;
-  long res;
-
-  va_start(ap);			/* init ap */
-
-  print = va_arg(ap,boolean);	/* get the condition */
-
-  if (print == 1)
-    { char* format = va_arg(ap,char*); /* get the format */
-      res = vprintf(format,ap);	/* print the contents */
-    }
-  else
-    res = 0;
-
-  va_end(ap);			/* free ap */
-
-  return(res);
-}
-
-  
-#endif
 
 /* 
    Define them here! Goes to libwais.a. So will be included in all
@@ -597,40 +552,21 @@ FILE* waislogfile = NULL;
 char *syslog_name = 0;
   
 void
-#ifdef ANSI_LIKE
 waislog(long priority, long message, char *format, ...)
-#else
-waislog(va_alist)
-va_dcl
-#endif
   {
   va_list ap;
-#ifndef ANSI_LIKE
-  int priority, message;
-  char *format;
-  
-  va_start(ap);
-  priority = va_arg(ap, int);
-  message = va_arg(ap, int);
-  format = va_arg(ap, char *);
-  vwaislog(priority, message, format, ap);
-  va_end(ap);
-#else
+#ifdef STDC_HEADERS
   va_start(ap, format);
+#else
+  va_start(ap);
+#endif
   vwaislog(priority, message, format, ap);
   va_end(ap);
-#endif
   }
   
   void
-#ifdef ANSI_LIKE /* use ansi varargs */
+
 vwaislog(long priority, long message, char* format, va_list ap)
-#else
-vwaislog(priority, message, format, ap)
-long priority, message;
-char *format;	
-va_list ap;
-#endif /* ANSI_LIKE */
   /* just like printf, but prints to the waislogfile, with PID and time. */
   {
   static boolean in_vwaislog; /* to avoid reentrancy problems if */
@@ -921,7 +857,7 @@ beFriendly()
 }
 
 
-#ifndef HAS_VPRINTF
+#ifndef HAVE_VPRINTF
 /* Portable vsprintf  by Robert A. Larson <blarson@skat.usc.edu> */
 
 /* Copyright 1989 Robert A. Larson.
@@ -987,6 +923,7 @@ typedef void *pointer;
 
 typedef int *intp;
 
+#ifndef HAVE_VSPRINTF
 int vsprintf(dest, format, args)
 char *dest;
 register char *format;
@@ -1095,8 +1032,9 @@ continue_format:
     *dp = '\0';
     return dp - dest;
 }
+#endif /* ifndef HAVE_VSPRINTF */
 
-
+#ifndef HAVE_VFPRINTF
 int vfprintf(dest, format, args)
 FILE *dest;
 register char *format;
@@ -1208,17 +1146,20 @@ continue_format:
     }
     return count;
 }
+#endif /* ifndef HAVE_VFPRINTF */
 
+#ifndef HAVE_VPRINTF
 vprintf(format, args)
 char *format;
 va_list args;
 {
     return vfprintf(stdout, format, args);
 }
-
+#endif /* ifndef HAVE_VPRINTF */
 #endif
 
-#ifndef HAS_STRDUP
+
+#ifndef HAVE_STRDUP
 char* strdup(s)
 const char* s;
 
