@@ -1,5 +1,6 @@
 
-/*  A Bison parser, made from field_y.y with Bison version GNU Bison version 1.24
+/*  A Bison parser, made from ./field_y.y
+ by  GNU Bison version 1.25
   */
 
 #define YYBISON 1  /* Identify Bison output.  */
@@ -28,10 +29,11 @@
 #define	STRING	279
 #define	DESCRIPTION	280
 
+#line 52 "./field_y.y"
 
 #include "cutil.h"
 #include <stdio.h>
-#include <ctype.h>
+#include <ctype.h>  /* local version redefines string functions */            
 #include "futil.h"
 #include "field_index.h"
 #include "field.h"
@@ -73,71 +75,55 @@ static boolean index_kind_both = false;
 
 static char** regexp_set = NULL;    /* contains regexp */
 
-static void clear_regexp _AP((long number_of_elements));
-static void make_ntable _AP((long *pos));
-static void make_index_fields _AP((long number_of_elements));
-static void put_end_tag_ftable _AP((long field_id, 
-                                    long regexp_pos));
-static void put_index_fields _AP((char* field_name, 
-                                  char* field_description, 
-                                  long field_id,
-long regexp_pos,
-long index_pos,
-boolean field_exists));
-static void put_numeric_ftable _AP((long n_index_pos,
-                                    int n_len,
-                                    long field_id));
-static void put_headline _AP((long begin_tag_pos,
-                              long end_tag_pos,
-                              long hline_begin_tag_pos,
-                              long n_len,
-                              long n_offset,
-                              long number_of_elements));
+static void clear_regexp (long number_of_elements);
+static void make_ntable (long *pos);
+static void make_index_fields (long number_of_elements);
+static void put_end_tag_ftable (long field_id, 
+				long regexp_pos);
+static void put_index_fields (char* field_name, 
+			      char* field_description, 
+			      long field_id,
+			      long regexp_pos,
+			      long index_pos,
+			      boolean field_exists);
+static void put_numeric_ftable (long n_index_pos,
+				int n_len,
+				long field_id);
+static void put_headline (long begin_tag_pos,
+			  long end_tag_pos,
+			  long hline_begin_tag_pos,
+			  long n_len,
+			  long n_offset,
+			  long number_of_elements);
 static long Maxhealine = 0;
 static long Nheadline = 0;
-static void put_record_end_Ltable _AP((long regexp_pos));
-static void put_hdate_ltable _AP((long begin_tag_pos,
-                                  DateDescription *date_desc,
-                                  long date_begin_tag_pos));
+static void put_record_end_Ltable (long regexp_pos);
+static void put_hdate_ltable (long begin_tag_pos,
+			      DateDescription *date_desc,
+			      long date_begin_tag_pos);
 static long Maxregexp = 0;
 
-static long insert_regexp _AP((char* regexp,
-                               long number_of_elements,
-                               long* regexp_pos));
-static long create_index_fields _AP((FILE* stream));
-static void put_indextypes _AP((char* itype,
-                                int i_kind,
-                                long field_id,
-                                long ipos));
-static void put_tags_in_gdb _AP((long field_id,
-				 long begin_tag_pos,
-				 long end_tag_pos, long index_pos,
-				 boolean *both,
-				 long *number_of_index_fields));
+static long insert_regexp (char* regexp,
+			   long number_of_elements,
+			   long* regexp_pos);
+static long create_index_fields (FILE* stream);
+static void put_indextypes (char* itype,
+			    int i_kind,
+			    long field_id,
+			    long ipos);
+static void put_tags_in_gdb (long field_id,
+			     long begin_tag_pos,
+			     long end_tag_pos, long index_pos,
+			     boolean *both,
+			     long *number_of_index_fields);
 
+#line 144 "./field_y.y"
 typedef union {
    int  ival;
    char *sval;
    char cval;
    DateDescription date;
    } YYSTYPE;
-
-#ifndef YYLTYPE
-typedef
-  struct fieldltype
-    {
-      int timestamp;
-      int first_line;
-      int first_column;
-      int last_line;
-      int last_column;
-      char *text;
-   }
-  fieldltype;
-
-#define YYLTYPE fieldltype
-#endif
-
 #include <stdio.h>
 
 #ifndef __cplusplus
@@ -214,12 +200,16 @@ static const short fieldrhs[] = {    27,
 
 #if YYDEBUG != 0
 static const short fieldrline[] = { 0,
-   142,   142,   144,   146,   148,   157,   158,   163,   164,   167,
-   168,   171,   185,   205,   206,   208,   219,   229,   300,   301,
-   307,   329,   338,   351,   371,   393,   394,   396,   397,   403,
-   423,   424,   425,   427,   438,   449,   465,   479,   480,   481,
-   484,   485,   488,   489,   492,   493
+   151,   151,   153,   155,   157,   166,   167,   172,   173,   176,
+   177,   180,   194,   214,   215,   217,   228,   238,   309,   310,
+   316,   338,   347,   360,   380,   402,   403,   405,   406,   412,
+   432,   433,   434,   436,   447,   458,   474,   488,   489,   490,
+   493,   494,   497,   498,   501,   502
 };
+#endif
+
+
+#if YYDEBUG != 0 || defined (YYERROR_VERBOSE)
 
 static const char * const fieldtname[] = {   "$","error","$undefined.","WORD","REGEXP",
 "FIELD","END","LAYOUT","STEMMING","ISOUNDEX","IPHONIX","NUMERIC","ITEXT","LOCAL",
@@ -227,7 +217,7 @@ static const char * const fieldtname[] = {   "$","error","$undefined.","WORD","R
 "YEAR","STRING","DESCRIPTION","docspec","parseformat","format","record","layout",
 "end","layoutspecs","layoutspec","speclist","spec","@1","@2","options","option",
 "regexp","indexspecs","indexspec","indextype","dicts","date_spec","date","monthspec",
-"descr","fieldlist",""
+"descr","fieldlist", NULL
 };
 #endif
 
@@ -303,7 +293,7 @@ static const short fieldcheck[] = {    24,
     16,    42,    11,    14
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-
+#line 3 "/usr/local/share/bison.simple"
 
 /* Skeleton output parser for bison,
    Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
@@ -458,16 +448,16 @@ int fieldparse (void);
 #endif
 
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
-#define __field_memcpy(FROM,TO,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
+#define __field_memcpy(TO,FROM,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
 #else				/* not GNU C or C++ */
 #ifndef __cplusplus
 
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__field_memcpy (from, to, count)
-     char *from;
+__field_memcpy (to, from, count)
      char *to;
+     char *from;
      int count;
 {
   register char *f = from;
@@ -483,7 +473,7 @@ __field_memcpy (from, to, count)
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__field_memcpy (char *from, char *to, int count)
+__field_memcpy (char *to, char *from, int count)
 {
   register char *f = from;
   register char *t = to;
@@ -496,7 +486,7 @@ __field_memcpy (char *from, char *to, int count)
 #endif
 #endif
 
-
+#line 196 "/usr/local/share/bison.simple"
 
 /* The user can define YYPARSE_PARAM as the name of an argument to be passed
    into fieldparse.  The argument should have type void *.
@@ -505,14 +495,20 @@ __field_memcpy (char *from, char *to, int count)
    to the proper pointer type.  */
 
 #ifdef YYPARSE_PARAM
-#define YYPARSE_PARAM_DECL void *YYPARSE_PARAM;
-#else
-#define YYPARSE_PARAM
+#ifdef __cplusplus
+#define YYPARSE_PARAM_ARG void *YYPARSE_PARAM
 #define YYPARSE_PARAM_DECL
-#endif
+#else /* not __cplusplus */
+#define YYPARSE_PARAM_ARG YYPARSE_PARAM
+#define YYPARSE_PARAM_DECL void *YYPARSE_PARAM;
+#endif /* not __cplusplus */
+#else /* not YYPARSE_PARAM */
+#define YYPARSE_PARAM_ARG
+#define YYPARSE_PARAM_DECL
+#endif /* not YYPARSE_PARAM */
 
 int
-fieldparse(YYPARSE_PARAM)
+fieldparse(YYPARSE_PARAM_ARG)
      YYPARSE_PARAM_DECL
 {
   register int fieldstate;
@@ -629,12 +625,12 @@ fieldnewstate:
       if (fieldstacksize > YYMAXDEPTH)
 	fieldstacksize = YYMAXDEPTH;
       fieldss = (short *) alloca (fieldstacksize * sizeof (*fieldssp));
-      __field_memcpy ((char *)fieldss1, (char *)fieldss, size * sizeof (*fieldssp));
+      __field_memcpy ((char *)fieldss, (char *)fieldss1, size * sizeof (*fieldssp));
       fieldvs = (YYSTYPE *) alloca (fieldstacksize * sizeof (*fieldvsp));
-      __field_memcpy ((char *)fieldvs1, (char *)fieldvs, size * sizeof (*fieldvsp));
+      __field_memcpy ((char *)fieldvs, (char *)fieldvs1, size * sizeof (*fieldvsp));
 #ifdef YYLSP_NEEDED
       fieldls = (YYLTYPE *) alloca (fieldstacksize * sizeof (*fieldlsp));
-      __field_memcpy ((char *)fieldls1, (char *)fieldls, size * sizeof (*fieldlsp));
+      __field_memcpy ((char *)fieldls, (char *)fieldls1, size * sizeof (*fieldlsp));
 #endif
 #endif /* no fieldoverflow */
 
@@ -795,6 +791,7 @@ fieldreduce:
   switch (fieldn) {
 
 case 5:
+#line 158 "./field_y.y"
 {
   number_of_regexp += 
       insert_regexp(fieldvsp[0].sval+1, number_of_regexp, &gregexp_pos);
@@ -804,9 +801,11 @@ case 5:
 ;
     break;}
 case 7:
+#line 169 "./field_y.y"
 {layout_specified = 1;;
     break;}
 case 12:
+#line 181 "./field_y.y"
 {
   long begin_tag_pos, date_begin_tag_pos;
 
@@ -822,6 +821,7 @@ case 12:
 ;
     break;}
 case 13:
+#line 195 "./field_y.y"
 {
   long hline_begin_tag_pos, begin_tag_pos, end_tag_pos;
 
@@ -841,6 +841,7 @@ case 13:
 ;
     break;}
 case 16:
+#line 218 "./field_y.y"
 {
   /* insert begin_tag */
 
@@ -852,6 +853,7 @@ case 16:
 ;
     break;}
 case 17:
+#line 228 "./field_y.y"
 {
   if(fieldlist_not_empty == 0) {
     if(save_index_fields(NULL, &number_of_index_fields, &gfield_id)) {
@@ -863,6 +865,7 @@ case 17:
 ;
     break;}
 case 18:
+#line 240 "./field_y.y"
 {
   if (!fieldlist_not_empty && !options_not_empty && !indexspecs_not_empty) {
     long            pos;
@@ -933,12 +936,14 @@ case 18:
 ;
     break;}
 case 20:
+#line 311 "./field_y.y"
 {
   options_not_empty = 1;
   fieldval.sval = fieldvsp[0].sval;
 ;
     break;}
 case 21:
+#line 317 "./field_y.y"
 {
   long            i, field_id;
 
@@ -962,6 +967,7 @@ case 21:
 ;
     break;}
 case 22:
+#line 339 "./field_y.y"
 {
     index_fields[gfield_id]->numeric = 1;
     index_fields[gfield_id]->numeric_len = 6; /* indicate date */
@@ -972,6 +978,7 @@ case 22:
 ;
     break;}
 case 23:
+#line 348 "./field_y.y"
 {
   long            i;
   long            field_id;
@@ -986,6 +993,7 @@ case 23:
 ;
     break;}
 case 24:
+#line 361 "./field_y.y"
 {
   long         fpos = index_fields[gfield_id]->number_of_Ftable;
   long         regexp_pos = index_fields[gfield_id]->Ftable[fpos].begin_tag_pos;
@@ -1007,6 +1015,7 @@ case 24:
 ;
     break;}
 case 25:
+#line 381 "./field_y.y"
 {
   long            regexp_pos1, regexp_pos2;
 
@@ -1029,18 +1038,22 @@ case 25:
 ;
     break;}
 case 26:
+#line 402 "./field_y.y"
 {fieldval.sval = NULL;;
     break;}
 case 27:
+#line 403 "./field_y.y"
 {fieldval.sval =fieldvsp[0].sval; ;
     break;}
 case 29:
+#line 407 "./field_y.y"
 {
   indexspecs_not_empty = 1;
   fieldval.sval = fieldvsp[0].sval;
 ;
     break;}
 case 30:
+#line 413 "./field_y.y"
 {
   long            i;
   long            field_id;
@@ -1061,6 +1074,7 @@ case 30:
 ;
     break;}
 case 34:
+#line 437 "./field_y.y"
 {
   if (fieldlist_not_empty) {
     fprintf (stderr, 
@@ -1073,6 +1087,7 @@ case 34:
 ;
     break;}
 case 35:
+#line 448 "./field_y.y"
 {
   if (fieldlist_not_empty == 0) {
     fprintf (stderr, "warning: %s\n",
@@ -1085,6 +1100,7 @@ case 35:
 ;
     break;}
 case 36:
+#line 459 "./field_y.y"
 {
   if (fieldlist_not_empty == 0) {
     fprintf (stderr, "warning: %s %s\n",
@@ -1100,6 +1116,7 @@ case 36:
 ;
     break;}
 case 37:
+#line 475 "./field_y.y"
 {
     DateDescription date;
     date.sscanf_arg       = strdup(fieldvsp[-3].sval+1); s_free(fieldvsp[-3].sval);
@@ -1114,27 +1131,35 @@ case 37:
 ;
     break;}
 case 38:
+#line 488 "./field_y.y"
 {fieldval.cval = 'd';;
     break;}
 case 39:
+#line 489 "./field_y.y"
 {fieldval.cval = fieldvsp[0].cval;;
     break;}
 case 40:
+#line 490 "./field_y.y"
 {fieldval.cval = 'y';;
     break;}
 case 41:
+#line 493 "./field_y.y"
 {fieldval.cval = 'm';;
     break;}
 case 42:
+#line 494 "./field_y.y"
 {fieldval.cval = 'M';;
     break;}
 case 43:
+#line 497 "./field_y.y"
 {fieldval.sval = NULL;;
     break;}
 case 44:
+#line 498 "./field_y.y"
 {fieldval.sval = fieldvsp[0].sval;;
     break;}
 case 46:
+#line 503 "./field_y.y"
 {
   ++number_of_fields_inserted;
   if (number_of_fields_inserted > 1) {
@@ -1167,7 +1192,7 @@ case 46:
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-
+#line 498 "/usr/local/share/bison.simple"
 
   fieldvsp -= fieldlen;
   fieldssp -= fieldlen;
@@ -1363,6 +1388,7 @@ fielderrhandle:
   fieldstate = fieldn;
   goto fieldnewstate;
 }
+#line 533 "./field_y.y"
 
 extern FILE* fieldin;
 extern int fieldlineno;
