@@ -10,6 +10,12 @@
 
 /* Change log:
  * $Log: futil.c,v $
+ * Revision 1.1.1.1  1996/06/04 20:36:14  julia
+ * autoconf baseline
+ *
+ * Revision 1.1.1.1  1996/04/30 18:22:15  dmitriy
+ * Version 2.1 -- autoconf baseline
+ *
  * Revision 2.0.1.3  1995/11/09 14:05:39  pfeifer
  * patch46:
  *
@@ -87,7 +93,7 @@
 */
 
 #ifndef lint
-static char *RCSid = "$Header: /usr/local/ls6/src+data/src/freeWAIS-sf-2.0/ir/RCS/futil.c,v 2.0.1.3 1995/11/09 14:05:39 pfeifer Exp $";
+static char *RCSid = "$Header: /usr/local/cvs/wais/freeWAIS-sf-2.1/ir/futil.c,v 1.1.1.1 1996/06/04 20:36:14 julia Exp $";
 #endif
 
 /* ======================== */
@@ -134,9 +140,6 @@ char* mode;
 #ifdef ultrix
 #define implicitBinary
 #endif /* def ultrix */
-#ifndef ANSI_LIKE
-#define implicitBinary
-#endif /* def ANSI_LIKE */
 
 
 
@@ -335,7 +338,7 @@ FILE* stream;
 
 /*----------------------------------------------------------------------*/
 
-static char *clean_path _AP((char* filename));
+static char *clean_path (char* filename);
 
 static char *clean_path(filename)
 char *filename;
@@ -390,7 +393,7 @@ char *full_path;
     return(full_path);
   }
   else{
-#ifdef HAS_GETCWD
+#ifdef HAVE_GETCWD
     getcwd(full_path, MAX_FILENAME_LEN);
 #else
     getwd(full_path);
@@ -494,7 +497,7 @@ char *current_user_name()
   strcpy(answer,"MAC"); /* could look up the name in the chooser */
 #else /* ndef THINK_C */
 
-#ifdef I_PWD
+#ifdef HAVE_PWD_H
 #include <pwd.h>  /* for getpwuid */
 #endif
 
