@@ -9,6 +9,15 @@
 
 /* Change log:
  * $Log: ir.c,v $
+ * Revision 1.3  1996/08/14 01:25:14  julia
+ * fixed memory leaks
+ *
+ * Revision 1.1.1.1  1996/06/04 20:36:15  julia
+ * autoconf baseline
+ *
+ * Revision 1.1.1.1  1996/04/30 18:22:15  dmitriy
+ * Version 2.1 -- autoconf baseline
+ *
  * Revision 2.0.1.4  1996/01/31 14:47:48  pfeifer
  * patch63: Use getcwd() is present.
  *
@@ -143,7 +152,7 @@
 */
 
 #ifndef lint
-static char *RCSid = "$Header: /usr/local/ls6/src+data/src/freeWAIS-sf-2.0/ir/RCS/ir.c,v 2.0.1.4 1996/01/31 14:47:48 pfeifer Exp $";
+static char *RCSid = "$Header: /usr/local/cvs/wais/freeWAIS-sf-2.1/ir/ir.c,v 1.3 1996/08/14 01:25:14 julia Exp $";
 #endif
 
 /*----------------------------------------------------------------------*/
@@ -198,57 +207,48 @@ then it should work.
 #include "sockets.h"  /* for connect_to_server */
 #include "panic.h"
 
-#include <ctype.h>
-/*
-#include <string.h>
-#include <math.h>
+#include <ctype.h> /* local version redefines string functions */
 
-#ifdef ANSI_LIKE
-#include <stdlib.h>
-#else
-#include "ustubs.h"
-#endif
-*/
 #include <sys/stat.h>
 #include "cdialect.h"
 
 /* forward declarations */
 
-static boolean needs_help _AP ((char *question));
+static boolean needs_help (char *question);
 
-static WAISDocumentHeader *help_header _AP((char *database_name, 
-					    char *index_directory));
+static WAISDocumentHeader *help_header (char *database_name, 
+					    char *index_directory);
 
-static WAISDocumentHeader *catalog_header _AP((char *database_name, 
+static WAISDocumentHeader *catalog_header (char *database_name, 
 					       char *index_directory,
-					       boolean results));
+					       boolean results);
 
-static void handleInit _AP((char** recBuf,char** sendBuf,
+static void handleInit (char** recBuf,char** sendBuf,
 			    long* sendBufLen,
-			    long* maxBufLen));
+			    long* maxBufLen);
                        
-static void handleSearch _AP((char** recBuf,char** sendBuf,
+static void handleSearch (char** recBuf,char** sendBuf,
 			      long* sendBufLen,
 			      long waisProtocolVersion,
-			      char *index_directory));
+			      char *index_directory);
 
-static void handleRelevanceFeedbackSearch _AP((SearchAPDU* search,
+static void handleRelevanceFeedbackSearch (SearchAPDU* search,
 					       char** sendBuf,long* sendBufLen,
 					       long waisProtocolVersion,
-					       char *index_directory));
+					       char *index_directory);
                                           
-static void handleElementRetrieval _AP((SearchAPDU* search,
+static void handleElementRetrieval (SearchAPDU* search,
 					char** sendBuf,
 					long* sendBufLen,
 					long waisProtocolVersion,
-					char *index_directory));
+					char *index_directory);
                                    
-static void handleFTPSearch _AP((SearchAPDU* search,
+static void handleFTPSearch (SearchAPDU* search,
 				 char** sendBuf,long* sendBufLen,
 				 long waisProtocolVersion,
-				 char *index_directory));
+				 char *index_directory);
 
-boolean server_security _AP((char *index_directory, char *database_name));
+boolean server_security (char *index_directory, char *database_name);
 
 #define isdoctype(doc, doctype) \
  (((doc) != NULL) && \
@@ -371,8 +371,8 @@ char *index_directory;
 
 /*----------------------------------------------------------------------*/
 
-static void handleInit _AP((char** recBuf,char** sendBuf,
-			    long* sendBufLen,long* maxBufferSize));
+static void handleInit (char** recBuf,char** sendBuf,
+			    long* sendBufLen,long* maxBufferSize);
 
 static void
 handleInit(recBuf,sendBuf,sendBufLen,maxBufferSize)
@@ -760,7 +760,8 @@ static WAISDocumentHeader *catalog_header(database_name, index_directory, result
   /* make a help document */
   hit catalog;
   char local_id[MAX_FILENAME_LEN + 60];
-
+  WAISDocumentHeader *temp = NULL; /*memory leak fix 08/13/96 JF */
+  
   strncpy(catalog.filename,
 	  merge_pathnames(database_name,index_directory), 
 	  MAX_FILENAME_LEN);
@@ -804,8 +805,8 @@ static WAISDocumentHeader *catalog_header(database_name, index_directory, result
       theDocID = makeDocID();
       theDocID->originalDatabase = stringToAny(database_name); /* XXX */
       theDocID->originalLocalID = stringToAny(local_id);
-
-      return(makeWAISDocumentHeader(anyFromDocID(theDocID),
+      
+      temp=makeWAISDocumentHeader(anyFromDocID(theDocID),
 				    UNUSED,
 				    (results ? MAX_NORMAL_SCORE:0),
 				    UNUSED,
@@ -814,8 +815,10 @@ static WAISDocumentHeader *catalog_header(database_name, index_directory, result
 				    s_strdup(database_name), /* XXX */
 				    NULL, /* date */
 				    s_strdup(catalog.headline),
-				    NULL));
-    }	
+				    NULL);
+   freeDocID(theDocID);
+   return(temp);
+   }	
   else 
     return(NULL);
 }
@@ -1191,6 +1194,7 @@ char *index_directory;
 
   /* francois - locks */
   closeDatabase(db);
+disposeDatabase(db); /* Memory leak fix JF 08/14/96 */
 }
 
 
@@ -1247,8 +1251,8 @@ char *index_directory;
 	*p='\0';
     }
 
-#ifdef HAS_GETCWD
-    getcwd(mpath,198);           /* up: was getwd ?? */
+#ifdef HAVE_GETCWD
+    getcwd(mpath,MAXPATHLEN);           
 #else
     getwd(mpath);
 #endif
