@@ -1,16 +1,6 @@
 /*                               -*- Mode: C -*- 
  * 
- * irtfiles.c -- 
- * ITIID           : $ITI$ $Header $__Header$
- * Author          : Jonny Goldman
- * Created On      : Fri Jun 23 16:36:37 1995
- * Last Modified By: Ulrich Pfeifer
- * Last Modified On: Thu Oct 12 14:36:14 1995
- * Language        : C
- * Update Count    : 17
- * Status          : Unknown, Use with caution!
- * 
- * (C) Copyright 1995, Universitt Dortmund, all rights reserved.
+ * (C) Copyright 1995, Universitdt Dortmund, all rights reserved.
  * 
  * $$
  */
@@ -26,6 +16,29 @@
 
 /* Change log:
  * $Log: irtfiles.c,v $
+ * Revision 1.2  1996/06/05 18:07:07  julia
+ * Fixed qsort warnings
+ *
+ * Revision 1.1.1.1  1996/06/04 20:36:33  julia
+ * autoconf baseline
+ *
+ * Revision 1.1.1.1  1996/04/30 18:22:29  dmitriy
+ * Version 2.1 -- autoconf baseline
+ *
+ * Revision 1.1.1.2  1996/04/23  19:45:12  dmitriy
+ * autoconf baseline
+ *
+ *
+ * Revision 1.2  1996/02/08  19:37:11  dmitriy
+ * patch 67  Fix bug reported by Timothy S. Pillsbury 
+ * tpill@cals.lasc.lockheed.com
+ * waisindex fails when indexing files in printerleaf format
+ * cause: line[char_count - 2] produces a segmentation fault 
+ * when char_count - 2 is less than 0.
+ *
+ * Revision 1.1  1996/01/11  20:37:57  dmitriy
+ * freeWAIS-sf.2.0 patchlevel 60 - we start our work from here
+ *
  * Revision 2.0.1.3  1995/10/16 12:45:08  pfeifer
  * patch38: Passed dataops->type to how_index_line if dataops->indextype
  * patch38: is not given. this is obviously a hack.
@@ -267,11 +280,11 @@ make_joint_word (word1, word2)
 }
 
 /* returns 0 is successful, non-0 if error */
-static long add_word_before_pairs _AP ((char *word, long char_pos,
+static long add_word_before_pairs (char *word, long char_pos,
 					long line_pos, long weight,
 					long doc_id, time_t date,
 					boolean capitalized, database * db,
-				boolean word_position, boolean word_pairs));
+				boolean word_position, boolean word_pairs);
 
 static long
 add_word_before_pairs (word, char_pos, line_pos,
@@ -337,11 +350,11 @@ add_word_before_pairs (word, char_pos, line_pos,
   return (add_word (word, char_pos, line_pos, weight, doc_id, date, 0L, db, word_position));
 }
 
-static long field_add_word_before_pairs _AP ((char *word, long char_pos,
+static long field_add_word_before_pairs (char *word, long char_pos,
 					      long line_pos, long weight,
 					      long doc_id, time_t date,
 					 boolean capitalized, database * db,
-				boolean word_position, boolean word_pairs));
+				boolean word_position, boolean word_pairs);
 
 static long
 field_add_word_before_pairs (word, char_pos, line_pos,
@@ -415,7 +428,7 @@ field_add_word_before_pairs (word, char_pos, line_pos,
 #ifdef NOTUSED
 #define WORD_LETTERS  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 
-static char    *new_word _AP ((char *line, char *word));
+static char    *new_word (char *line, char *word);
 
 static char    *
 new_word (line, word)
@@ -449,7 +462,7 @@ new_word (line, word)
   return (next_word);
 }
 
-static boolean reasonable_word _AP ((char *word));
+static boolean reasonable_word (char *word);
 
 static          boolean
 reasonable_word (word)
@@ -760,10 +773,16 @@ map_over_words (line,
      }
    */
   if (newline_terminated != NULL) {
-    if ('\n' != line[char_count - 2])
-      *newline_terminated = false;
+    if (char_count > 1)
+      if ('\n' != line[char_count - 2])
+        *newline_terminated = false;
+      else
+        *newline_terminated = true;
     else
-      *newline_terminated = true;
+        if ('\n' != line[0])
+           *newline_terminated = false;
+        else
+           *newline_terminated = true;
   }
   if (line_length != NULL)
     *line_length = char_count - 1;
@@ -771,10 +790,11 @@ map_over_words (line,
 }
 
 static long     add_words_if_appropriate
-                _AP ((char *line, long document_id, long weight, long file_position_before_line,
+             (char *line, long document_id, long weight, 
+	     long file_position_before_line,
 	     long *line_length, boolean * newline_terminated, database * db,
-		      boolean word_position, boolean word_pairs,
-		      int minwordlen));
+	     boolean word_position, boolean word_pairs,
+	     int minwordlen);
 
 static long
 add_words_if_appropriate (line,
@@ -935,15 +955,18 @@ add_words_if_appropriate (line,
   return (word_count);
 }
 
-static int nodecompare _AP ((unsigned long *i, unsigned long *j));
+static int nodecompare (const void  *i, const void *j);
 
 static int
-nodecompare (i, j)
-     unsigned long  *i, *j;
+nodecompare (i,j)
+     const void  *i; 
+     const void  *j;
 {
-  if (i[0] < j[0])
+const unsigned long *k = i;
+const unsigned long *l = j;
+  if (k[0] < l[0])
     return (-1);
-  else if (i[0] > j[0])
+  else if (k[0] > l[0])
     return (1);
   else
     return (0);
@@ -955,21 +978,21 @@ nodecompare (i, j)
 
 static void     finish_document
 #ifndef SOUND
-                _AP ((boolean recountHeader, char *header, char *line, long document_id,
+(boolean recountHeader, char *header, char *line, long document_id,
 		      document_table_entry * the_document_table_entry,
 		      long file_position_before_line,
 		      long file_position_before_document, database * db,
 		      boolean word_position, boolean word_pairs,
-		      int minwordlen));
+		      int minwordlen);
 
 #else					    /* SOUND */
-                _AP ((boolean recountHeader, char *header, char *line, long document_id,
+(boolean recountHeader, char *header, char *line, long document_id,
 		      document_table_entry * the_document_table_entry,
 		      long file_position_before_line,
 		      long file_position_before_document, database * db,
 		      boolean word_position, boolean word_pairs,
 		      int minwordlen,
-		      char *type));
+		      char *type);
 
 #endif /* SOUND */
 
