@@ -9,11 +9,23 @@
 
 
 #ifndef lint
-static char *RCSid = "$Header: /usr/local/ls6/src+data/src/freeWAIS-sf-2.0/ir/RCS/ui.c,v 2.0.1.2 1995/11/09 14:07:36 pfeifer Exp $";
+static char *RCSid = "$Header: /usr/local/cvs/wais/freeWAIS-sf-2.1/ir/ui.c,v 1.2 1996/08/08 23:20:09 julia Exp $";
 #endif
 
 /* Change log:
  * $Log: ui.c,v $
+ * Revision 1.2  1996/08/08 23:20:09  julia
+ * Fixed memory leak
+ *
+ * Revision 1.1.1.1  1996/06/04 20:36:50  julia
+ * autoconf baseline
+ *
+ * Revision 1.1.1.1  1996/04/30 18:22:33  dmitriy
+ * Version 2.1 -- autoconf baseline
+ *
+ * Revision 1.1.1.2  1996/04/23  19:43:55  dmitriy
+ * autoconf baseline
+ *
  * Revision 2.0.1.2  1995/11/09 14:07:36  pfeifer
  * patch46: added a fix from ui-local.c.
  *
@@ -73,9 +85,9 @@ static char *RCSid = "$Header: /usr/local/ls6/src+data/src/freeWAIS-sf-2.0/ir/RC
 #include "ustubs.h"
 #include "futil.h"
 
-#include <ctype.h>
+#include <ctype.h>              
+
 #include <errno.h>
-/* #include <string.h> */
 #include "cdialect.h"
 #include <sys/types.h>
 
@@ -253,6 +265,7 @@ char *userInfo;
     freeInitAPDU(init);
     return(-1);
   }
+freeInitAPDU(init);
   if(0 ==
      interpret_message(inBuffer,
 		       result - HEADER_LENGTH,
