@@ -18,11 +18,20 @@
 
 
 #ifndef lint
-static char *RCSid = "$Header: /usr/local/ls6/src+data/src/freeWAIS-sf-2.0/ir/RCS/wprot.c,v 2.0.1.1 1995/09/15 09:50:53 pfeifer Exp $";
+static char *RCSid = "$Header: /usr/local/cvs/wais/freeWAIS-sf-2.1/ir/wprot.c,v 1.1.1.1 1996/06/04 20:36:54 julia Exp $";
 #endif
 
 /* Change log:
  * $Log: wprot.c,v $
+ * Revision 1.1.1.1  1996/06/04 20:36:54  julia
+ * autoconf baseline
+ *
+ * Revision 1.1.1.1  1996/04/30 18:22:35  dmitriy
+ * Version 2.1 -- autoconf baseline
+ *
+ * Revision 1.1.1.2  1996/04/23  19:44:20  dmitriy
+ * autoconf baseline
+ *
  * Revision 2.0.1.1  1995/09/15 09:50:53  pfeifer
  * patch7: Fixed CNIDR copyright line.
  *
@@ -58,11 +67,7 @@ static char *RCSid = "$Header: /usr/local/ls6/src+data/src/freeWAIS-sf-2.0/ir/RC
 #include "wprot.h"
 #include "cutil.h"
 #include "panic.h"
-/* #include <string.h> /* for memmove */
 
-#ifndef ANSI_LIKE
-#include "ustubs.h"
-#endif
 
 /* very rough estimates of the size of an object */
 #define DefWAISInitResponseSize		(size_t)200
@@ -81,12 +86,11 @@ static char *RCSid = "$Header: /usr/local/ls6/src+data/src/freeWAIS-sf-2.0/ir/RC
      if (*len > 0)							\
      	*len -= header_len;
 
-static char* writeUserInfoHeader _AP((data_tag tag,long infoSize,	
+static char* writeUserInfoHeader (data_tag tag,long infoSize,	
 				      long estHeaderSize,char* buffer,
-				      long* len));
+				      long* len);
 
-static unsigned long userInfoTagSize _AP((data_tag tag,
-					  unsigned long length));
+static unsigned long userInfoTagSize (data_tag tag, unsigned long length);
 
 /*----------------------------------------------------------------------*/
 
@@ -112,8 +116,8 @@ long* len;
 
 /*----------------------------------------------------------------------*/
 
-static char* readUserInfoHeader _AP((data_tag* tag,unsigned long* num,
-				     char* buffer));
+static char* readUserInfoHeader (data_tag* tag,unsigned long* num,
+				     char* buffer);
 
 char*
 readInitInfo(info,buffer)
@@ -496,7 +500,7 @@ DocObj* doc;
 
 /*----------------------------------------------------------------------*/
 
-static char* writeDocObj _AP((DocObj* doc,char* buffer,long* len));
+static char* writeDocObj (DocObj* doc,char* buffer,long* len);
 
 static char*
 writeDocObj(doc,buffer,len)
@@ -543,7 +547,7 @@ long* len;
 
 /*----------------------------------------------------------------------*/
 
-static char* readDocObj _AP((DocObj** doc,char* buffer));
+static char* readDocObj (DocObj** doc,char* buffer);
 
 static char*
 readDocObj(doc,buffer)
@@ -1456,14 +1460,14 @@ long* len;
 /*----------------------------------------------------------------------*/
 
 static void
-cleanUpWaisSearchResponse _AP((char* buf,char* seedWordsUsed,
+cleanUpWaisSearchResponse (char* buf,char* seedWordsUsed,
 			       WAISDocumentHeader** docHeaders,
 			       WAISDocumentShortHeader** shortHeaders,
 			       WAISDocumentLongHeader** longHeaders,
 			       WAISDocumentText** text,
 			       WAISDocumentHeadlines** headlines,
 			       WAISDocumentCodes** codes,
-			       diagnosticRecord**diags));
+			       diagnosticRecord**diags);
 
 static void
 cleanUpWaisSearchResponse (buf,seedWordsUsed,docHeaders,shortHeaders,
@@ -2105,7 +2109,7 @@ char* buffer;
         ( XXX return type could be in the element set)
 */
 
-static query_term** makeWAISQueryTerms _AP((DocObj** docs));
+static query_term** makeWAISQueryTerms (DocObj** docs);
    
 static query_term**
 makeWAISQueryTerms(docs)
@@ -2224,7 +2228,7 @@ DocObj** docs;
 
 /*----------------------------------------------------------------------*/
 
-static DocObj** makeWAISQueryDocs _AP((query_term** terms));
+static DocObj** makeWAISQueryDocs (query_term** terms);
 
 static DocObj** 
 makeWAISQueryDocs(terms)
