@@ -12,6 +12,18 @@
  * -brewster 7/90
  *
  * $Log: waissearch.c,v $
+ * Revision 1.2  1996/08/14 23:51:05  julia
+ * FIxed memory leak
+ *
+ * Revision 1.1.1.1  1996/06/04 20:37:59  julia
+ * autoconf baseline
+ *
+ * Revision 1.1.1.1  1996/04/30 18:22:43  dmitriy
+ * Version 2.1 -- autoconf baseline
+ *
+ * Revision 1.1.1.1  1996/04/23  14:02:50  dmitriy
+ * Version 2.0
+ *
  * Revision 2.0.1.2  1995/09/15 09:55:57  pfeifer
  * patch7: Fixed CNIDR copyright line.
  *
@@ -104,7 +116,7 @@
  */
 
 #ifndef lint
-static char *RCSid = "$Header: /usr/local/ls6/src+data/src/freeWAIS-sf-2.0/ui/RCS/waissearch.c,v 2.0.1.2 1995/09/15 09:55:57 pfeifer Exp $";
+static char *RCSid = "$Header: /usr/local/cvs/wais/freeWAIS-sf-2.1/ui/waissearch.c,v 1.2 1996/08/14 23:51:05 julia Exp $";
 #endif
 
 #include <ui.h>
@@ -264,7 +276,7 @@ char *argv[];
 
   database[0] = '\0';  /* null it out */
   service[0] = '\0';
-
+ 
   if(NULL == (next_argument = next_arg(&argc, &argv))){
     printf("No arguments specified\n");
     exit(0);
@@ -644,7 +656,8 @@ char *argv[];
 	      (query_info->DocHeaders[document_number - 1]->DocumentLength == 0) ||
 	      (count * CHARS_PER_PAGE <
 	      query_info->DocHeaders[document_number - 1]->DocumentLength);
-	      count++){
+	      count++)
+	  {
 	    char *type;
 	    if(query_info->DocHeaders[document_number - 1]->Types == NULL)
 	      type = s_strdup("TEXT");
@@ -717,7 +730,8 @@ char *argv[];
 	      showDiags(((WAISSearchResponse *)retrieval_response->DatabaseDiagnosticRecords)->Diagnostics);
 	      break;
 	    }
-	  }
+	  s_free(type);
+	  }  /*end of for*/
 	  freeWAISSearchResponse( retrieval_response->DatabaseDiagnosticRecords); 
 	  freeSearchResponseAPDU( retrieval_response);
 	}
