@@ -13,6 +13,15 @@
 
 /*
  * $Log: qdisplay.h,v $
+ * Revision 1.1.1.1  1996/06/04 20:38:46  julia
+ * autoconf baseline
+ *
+ * Revision 1.1.1.1  1996/04/30 18:22:46  dmitriy
+ * Version 2.1 -- autoconf baseline
+ *
+ * Revision 1.1.1.2  1996/04/23  19:47:33  dmitriy
+ * autoconf baseline
+ *
  * Revision 2.0.1.1  1995/09/15 09:57:05  pfeifer
  * patch7: Fixed CNIDR copyright line.
  *
@@ -39,15 +48,15 @@
 #ifndef _H_QDISPLAY
 #define _H_QDISPLAY
 
-void SetqIcon _AP((Widget parent));
-void SettIcon _AP((Widget parent));
-Widget MakeQuestionPane _AP((Widget parent,XQuestion question));
-Widget MakeTextPopup _AP((Widget parent,Textbuff t,char *name));
-QuestionWindow MakeQuestionForm _AP((XQuestion question));
-Widget MakeSourcePopup _AP((Widget parent));
-Widget MakePrefPopup _AP((Widget parent));
-ScrollList MakeSourceFrame _AP((Widget parent));
-ScrollList MakeTypeFrame _AP((Widget parent));
-void MakeWaisCursors _AP((void));
+void SetqIcon (Widget parent);
+void SettIcon (Widget parent);
+Widget MakeQuestionPane (Widget parent,XQuestion question);
+Widget MakeTextPopup (Widget parent, Textbuff t, char *name);
+QuestionWindow MakeQuestionForm (XQuestion question);
+Widget MakeSourcePopup (Widget parent);
+Widget MakePrefPopup (Widget parent);
+ScrollList MakeSourceFrame (Widget parent);
+ScrollList MakeTypeFrame (Widget parent);
+void MakeWaisCursors (void);
 #endif
 
